summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGMaskElementImpl.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /ksvg/impl/SVGMaskElementImpl.h
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'ksvg/impl/SVGMaskElementImpl.h')
-rw-r--r--ksvg/impl/SVGMaskElementImpl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksvg/impl/SVGMaskElementImpl.h b/ksvg/impl/SVGMaskElementImpl.h
index 2a96967c..5b61d713 100644
--- a/ksvg/impl/SVGMaskElementImpl.h
+++ b/ksvg/impl/SVGMaskElementImpl.h
@@ -89,10 +89,10 @@ public:
Mask createMask(SVGShapeImpl *referencingElement);
// Compute the mask on a given shape, taking into account all masks defined
// on the shape's ancestors. This is a workaround for us not having a buffer
// for container elements, so we can't mask containers directly.
- static TQByteArray maskRectangle(SVGShapeImpl *shape, const TQRect& screenRectangle);
+ static TQByteArray maskRectangle(SVGShapeImpl *tqshape, const TQRect& screenRectangle);
private:
class CacheKey
@@ -89,10 +89,10 @@ public:
Mask createMask(SVGShapeImpl *referencingElement);
- // Compute the mask on a given shape, taking into account all masks defined
- // on the shape's ancestors. This is a workaround for us not having a buffer
+ // Compute the mask on a given tqshape, taking into account all masks defined
+ // on the tqshape's ancestors. This is a workaround for us not having a buffer
// for container elements, so we can't mask containers directly.